=======
zemfrog
=======

.. image:: https://raw.githubusercontent.com/zemfrog/zemfrog/master/docs/_static/logo.png
        :target: https://zemfrog.readthedocs.io
        :alt: zemfrog logo

.. image:: https://img.shields.io/pypi/v/zemfrog.svg
        :target: https://pypi.python.org/pypi/zemfrog

.. image:: https://img.shields.io/travis/zemfrog/zemfrog.svg
        :target: https://travis-ci.com/zemfrog/zemfrog

.. image:: https://readthedocs.org/projects/zemfrog/badge/?version=latest
        :target: https://zemfrog.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status



Zemfrog is a powerful boilerplate for flask.
Which focuses on building API structures that are easy to customize, flexible and manageable!
We believe zemfrog can speed up your work with flask and please help us develop this boilerplate!

* Free software: MIT license
* Documentation: https://zemfrog.readthedocs.io.


Notes
-----

It should be noted. currently, the zemfrog project is still under development. So we are not responsible for the instability of zemfrog features.


Features
--------

* Solid application structure.
* Automation creates APIs based on tables in the database.
* Automation creates schema models for your ORM.
* Easy to add your commands.
* Easy to add extensions.
* Easy to add task queue to celery.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
